from awlify.utils.check_word import check_word_in_list
import spacy

nlp = spacy.load('en_core_web_sm')


def check_word_in_sentence(sentence):
    if not isinstance(sentence, str):
        raise Exception('input must be a string')

    doc = nlp(sentence)

    tokenized = [token.text for token in doc]
    awl_words = []

    for word in tokenized:
        if (check_word_in_list(word) is not None):
            index = tokenized.index(word)
            awl_words.append({
                'index': index,
                'word': word,
                'meta': check_word_in_list(word)
            })
        else:
            continue

    return {'data': {'sentence': sentence, 'awl_words': awl_words}}



import pathlib
from setuptools import find_packages, setup

HERE = pathlib.Path(__file__).parent

README = (HERE / "README.md").read_text()

# calls setup() to install
setup(
    name="awlify",
    version="1.0.0",
    description="a simple utility to take in a sentence and "
                "output information about the AWL words in it",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/lpmi-13/awlify-python",
    author="Adam Leskis",
    author_email="leskis@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
    ],
    packages=find_packages(exclude=('tests',)),
    install_requires=["spacy>=2.0.16"],
)
